@@ -16,6 +16,8 @@
 
 #include <KAboutData>
 #include <KConfig>
+#include <KCrash>
+#include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KSandbox>
@@ -23,8 +25,6 @@
 #include <QApplication>
 #include <QCommandLineParser>
 
-#include <KDBusService>
-
 QCommandLineParser *createParser()
 {
     QCommandLineParser *parser = new QCommandLineParser;
@@ -48,6 +48,8 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Han Young"), QLatin1String(), QStringLiteral("hanyoung@protonmail.com"));
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     // ~~~~ Parse command line arguments ~~~~
     {
         QScopedPointer<QCommandLineParser> parser(createParser());
